@@ -26,7 +26,7 @@
 
 setMethod("sample", signature(x = "itemMatrix"),
     function(x, size, replace = FALSE, prob = NULL, ...) {
-        index <- sample(c(1:length(x)), size = size, 
+        index <- sample(c(seq_len(length(x))), size = size, 
             replace = replace, prob = prob)
         
         x[index]
@@ -34,7 +34,7 @@ setMethod("sample", signature(x = "itemMatrix"),
 
 setMethod("sample", signature(x = "associations"),
     function(x, size, replace = FALSE, prob = NULL, ...) {
-        index <- sample(c(1:length(x)), size = size, 
+        index <- sample(c(seq_len(length(x))), size = size, 
             replace = replace, prob = prob)
         
         x[index]
